// Script header for module 'PullDownMenus'
//
// Author: Steve McCrea (SteveMcCrea)
// 
// Abstract: Provides configurable pull down menus for AGS
//   Uses a mac-style drag and release because clicks outside the GUIs aren't detectable
//
// Dependencies: AGS 2.72 or later
//
// Configuration:
//
//   Create two new GUIs and a new Character
//   The bar GUI is not resized, but the items GUI is
//   Call all the 'Set' functions
//

struct __PullDownMenus {

  // call this on QuitGame, or when removing the menus
  import function Reset();
  // the font used and the pixel spacing around each menu item
  import function SetFontAndSpacing(int font, int hspacing, int vspacing);
  // these GUIs should by newly created, empty GUIs
  import function SetBarAndItemsGUIs(GUI *bar, GUI *items);
  // the colours of the background, text, and text of disabled item (if the border == background, no border)
  import function SetColours(int backgroundColour, int foregroundColour, int disabledColour, int borderColour);
  // a dummy character that is used to receive "callbacks" through the Interact script
  // use GetClickedMenuName and GetClickedItemName to identify the menu item clicked
  import function SetCallbackCharacter(Character *callbackCharacter);
  // generally eModePointer (but you may not have that)
  import function SetCursor(int cursor);
  // optional - otherwise draws a tick
  import function SetTickIcon(int tick);
  // optional - graphics to tile on the GUI
  import function SetBackgroundGraphics(int barGraphic, int itemsGraphic);
  // adds a top level menu
  import function AddMenu(String menuName);
  // used to check how many menus have been added
  import int MenuCount();
  // turn off menus
  import function HideMenus();
  // turn on menus
  import function ShowMenus();
  // adds an item to a top level menu
  import function AddMenuItem(String menuName, String itemName, int icon = -1);
  // adds a toggleable item to a top level menu (with a check mark)
  import function AddMenuItemToggle(String menuName, String itemName, bool on);
  // adds a divider to a top level menu
  import function AddMenuItemDivider(String menuName);
  // enables a menu item
  import function EnableMenuItem(String menuName, String itemName);
  // sets the right justified text of a menu item (eg the key shortcut)
  import function SetMenuItemRightText(String menuName, String itemName, String rightText);
  // disables (greys out) a menu item - it won't send a callback
  import function DisableMenuItem(String menuName, String itemName);
  // toggles on a toggleable menu item
  import function ToggleOnMenuItem(String menuName, String itemName);
  // toggles off a toggleable menu item
  import function ToggleOffMenuItem(String menuName, String itemName);
  // toggles a toggleable menu item
  import function ToggleMenuItem(String menuName, String itemName);
  // call this from the callback character Interact script to identify the menu
  import String GetClickedMenuName();
  // call this from the callback character Interact script to identify the menu item clicked
  import String GetClickedItemName();
  // determine if a toggleable menu item is on (if it doesn't exist, this returns false)
  import bool IsMenuItemOn(String menuName, String itemName);
};

import __PullDownMenus PullDownMenus;

//
// Revision History:
//
// 4 June 2006: v1.3  Added borders, tiled backgrounds, flash on select
// 2 June 2006: v1.2  Changed to mac style, added right text to items
// 1 June 2006: v1.1  Added icons, allowed menu bar move/scale, and fixed autocomplete
// 1 June 2006: v1.0  First release
//
// Licence:
//
//   PullDownMenus AGS script module
//   Copyright (c) 2006 Steve McCrea
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to 
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in 
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
